summaryrefslogtreecommitdiff
path: root/utils/src/env
diff options
context:
space:
mode:
Diffstat (limited to 'utils/src/env')
-rw-r--r--utils/src/env/helpdoc.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/utils/src/env/helpdoc.rs b/utils/src/env/helpdoc.rs
index d9bce2c..ab2570e 100644
--- a/utils/src/env/helpdoc.rs
+++ b/utils/src/env/helpdoc.rs
@@ -1,6 +1,6 @@
/// Gets the default help documentation setting based on environment variables.
///
/// The function checks the JV_HELPDOC environment variable.
/// If the variable is set to "1", it returns true (enabled).
/// If the variable is set to any other value, it returns false (disabled).
/// If the variable is not set, it returns true (enabled by default).
@@ -8,7 +8,7 @@
/// # Returns
/// A boolean indicating whether help documentation is enabled
pub fn get_helpdoc_enabled() -> bool {
- match std::env::var("JV_HELPDOC") {
+ match std::env::var("JV_HELPDOC_VIEWER") {
Ok(value) => value == "1",
Err(_) => true,
}
@@ -1,6 +1,6 @@
/// Gets the default help documentation setting based on environment variables.
///
-/// The function checks the JV_HELPDOC environment variable.
+/// The function checks the JV_HELPDOC_VIEWER environment variable.
/// If the variable is set to "1", it returns true (enabled).
/// If the variable is set to any other value, it returns false (disabled).